@@ -64,6 +64,8 @@ class _ADA_DATETIME_MIXIN:
                         return datetime.datetime.strptime(value, "%Y-%m-%d").date()
                     if self.py_type == datetime.time:
                         return datetime.datetime.strptime(value, "%H:%M:%S").time()
+                    if "." in value:
+                        return datetime.datetime.strptime(value, "%Y-%m-%d %H:%M:%S.%f")
                     return datetime.datetime.strptime(value, "%Y-%m-%d %H:%M:%S")
             return value
         return process
@@ -73,16 +75,31 @@ class _ADA_DATE(_ADA_DATETIME_MIXIN, DATE):
     py_type = datetime.date
     sa_type = sqltypes.Date
 
+    def bind_processor(self, dialect):
+        def process(value):
+            return value.strftime("%Y-%m-%d") if isinstance(value, self.py_type) else value
+        return process
+
 
 class _ADA_TIME(_ADA_DATETIME_MIXIN, TIME):
     py_type = datetime.time
     sa_type = sqltypes.Time
 
+    def bind_processor(self, dialect):
+        def process(value):
+            return value.strftime("%H:%M:%S") if isinstance(value, self.py_type) else value
+        return process
+
 
 class _ADA_TIMESTAMP(_ADA_DATETIME_MIXIN, TIMESTAMP):
     py_type = datetime.datetime
     sa_type = sqltypes.DateTime
 
+    def bind_processor(self, dialect):
+        def process(value):
+            return value.strftime("%Y-%m-%d %H:%M:%S") if isinstance(value, self.py_type) else value
+        return process
+
 
 class _ADA_ARRAY(ARRAY):
     def bind_processor(self, dialect):
@@ -99,11 +116,13 @@ class AuroraMySQLDataAPIDialect(MySQLDialect):
     # See https://docs.sqlalchemy.org/en/13/core/internals.html#sqlalchemy.engine.interfaces.Dialect
     driver = "aurora_data_api"
     default_schema_name = None
+    supports_native_decimal = True
     colspecs = util.update_copy(MySQLDialect.colspecs, {
         sqltypes.Date: _ADA_DATE,
         sqltypes.Time: _ADA_TIME,
         sqltypes.DateTime: _ADA_TIMESTAMP,
     })
+    supports_statement_cache = True
 
     @classmethod
     def dbapi(cls):
@@ -131,11 +150,16 @@ class AuroraPostgresDataAPIDialect(PGDialect):
         sqltypes.Enum: _ADA_ENUM,
         ARRAY: _ADA_ARRAY
     })
+    supports_sane_multi_rowcount = False
+    supports_statement_cache = True
 
     @classmethod
     def dbapi(cls):
         return aurora_data_api
 
+    def _extract_error_code(self, exception):
+        return exception.args[0].value
+
 
 def register_dialects():
     from sqlalchemy.dialects import registry
